@@ -17,7 +17,7 @@
  *
  * This file extends the generic "jtag" class for the mkII protocol.
  *
- * $Id: jtag2.h,v 1.8 2006/09/15 21:51:47 joerg_wunsch Exp $
+ * $Id: jtag2.h,v 1.11 2006/10/28 21:31:31 joerg_wunsch Exp $
  */
 
 #ifndef JTAG2_H
@@ -112,7 +112,8 @@ class jtag2: public jtag
     breakpoint2 softBPcache[MAX_BREAKPOINTS2];
 
   public:
-    jtag2(const char *dev, char *name, bool useDW = false): jtag(dev, name) {
+    jtag2(const char *dev, char *name, bool useDW = false, bool is_dragon = false):
+      jtag(dev, name, is_dragon? EMULATOR_DRAGON: EMULATOR_JTAGICE) {
 	signedIn = haveHiddenBreakpoint = false;
 	command_sequence = 0;
 	devdescrlen = sizeof(jtag2_device_desc_type);
