@@ -20,7 +20,7 @@
  * This file implements those parts of class "jtag" that are common
  * for both, the mkI and mkII protocol.
  *
- * $Id: jtaggeneric.cc,v 1.6 2006/09/12 20:40:10 joerg_wunsch Exp $
+ * $Id: jtaggeneric.cc,v 1.7 2006/10/28 20:17:31 joerg_wunsch Exp $
  */
 
 #include <stdarg.h>
@@ -71,12 +71,13 @@ jtag::jtag(void)
   oldtioValid = is_usb = false;
 }
 
-jtag::jtag(const char *jtagDeviceName, char *name)
+jtag::jtag(const char *jtagDeviceName, char *name, emulator type)
 {
     struct termios newtio;
 
     device_name = name;
     is_usb = false;
+    emu_type = type;
 #ifdef HAVE_LIBUSB
     if (strncmp(jtagDeviceName, "usb", 3) == 0)
       {
